;; Generated package description from bluetooth.el  -*- no-byte-compile: t -*-
(define-package "bluetooth" "0.3.1.0.20220422.92625" "A Major mode for Bluetooth devices" '((emacs "25.1") (dash "2.18.1")) :commit "84488dfdd2355e512f9e9444a233448221b3d9cc" :authors '(("Raffael Stocker" . "r.stocker@mnet-mail.de") ("Etienne Prud’homme" . "e.e.f.prudhomme@gmail.com")) :maintainer '("Raffael Stocker" . "r.stocker@mnet-mail.de") :keywords '("hardware") :url "https://gitlab.com/rstocker/emacs-bluetooth")
